package com.xhpc.system.mapper;

import com.xhpc.system.domain.XhpcUserPrivilege;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 数据权限 数据层
 *
 * @author ruoyi
 */
public interface XhpcUserPrivilegeMapper {


    /**
     * 新增数据权限
     *
     * @param xhpcUserPrivilege 用户信息
     * @return 结果
     */
    public int insert(XhpcUserPrivilege xhpcUserPrivilege);

    /**
     * 通过用户ID删除用户数据权限
     *
     * @param userId 用户ID
     * @return 结果
     */
    public int delete(Long userId);


    /**
     * 用户拥有数据权限
     *
     * @param userId 用户id
     * @return 结果
     */
    public List<Long> dataCheckedKeys(@Param("userId") Long userId);

    /**
     * 通过运营商id查询运营商
     *
     * @param operatorIds 用户id
     * @return 结果
     */
    public List<Map<String, Object>> getOperatorId(@Param("operatorIds") String[] operatorIds);

    /**
     * 通过用户id查询运营商
     *
     * @param userId 用户id
     * @return 结果
     */
    public List<Map<String, Object>> getOperatorIdByUserId(@Param("userId") Long userId);

    /**
     * 通过运营商id分组查询省地址
     *
     * @param operatorId 运营商id
     * @return 结果
     */
    public List<Map<String, Object>> groupProvinceByOperatorId(@Param("userId") Long userId,@Param("operatorId") Long operatorId);

    /**
     * 通过运营商id分组查询市地址
     *
     * @param operatorId 运营商id
     * @return 结果
     */
    public List<Map<String, Object>> groupCityByOperatorId(@Param("userId") Long userId,@Param("provinceCode") String provinceCode,@Param("operatorId") Long operatorId);

    /**
     * 通过运营商id分组查询市地址
     *
     * @param operatorId 运营商id
     * @return 结果
     */
    public List<Map<String, Object>> groupAreaByOperatorId(@Param("userId") Long userId,@Param("cityCode") String cityCode,@Param("operatorId") Long operatorId);

    /**
     * 通过运营商id分组查询市地址
     *
     * @param operatorId 运营商id
     * @return 结果
     */
    public List<Map<String, Object>> dataPowerByOperatorId(@Param("userId") Long userId,@Param("code") String cityCode,@Param("operatorId") Long operatorId);
}
